// Auth Database to verify logins

unit Auth.Database;

interface

uses
  System.SysUtils, System.Classes, IniFiles, Vcl.Forms, MemDS,
  Data.DB, DBAccess, Uni, UniProvider, PostgreSQLUniProvider, MySQLUniProvider;

type
  TAuthDatabase = class(TDataModule)
    uq: TUniQuery;
    uqMisc: TUniQuery;
    ucKG: TUniConnection;
    MySQLUniProvider1: TMySQLUniProvider;
    procedure DataModuleCreate(Sender: TObject);
    procedure DataModuleDestroy(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  AuthDatabase: TAuthDatabase;

implementation

uses
  System.JSON,
  Common.Config,
  Common.Logging,
  uLibrary;

{%CLASSGROUP 'Vcl.Controls.TControl'}

{$R *.dfm}

procedure TAuthDatabase.DataModuleCreate(Sender: TObject);
var
  iniFile: TIniFile;
  iniStr: string;
begin
  iniFile := TIniFile.Create( ExtractFilePath(Application.ExeName) + 'kgOrdersServer.ini' );
  try

    iniStr := iniFile.ReadString('Database', 'Server', '');
    if not iniStr.IsEmpty then
      ucKG.Server := iniStr;
    iniStr := iniFile.ReadString('Database', 'Database', '');
    if not iniStr.IsEmpty then
      ucKG.Database := iniStr;
    iniStr := iniFile.ReadString('Database', 'Username', '');
    if not iniStr.IsEmpty then
      ucKG.Username := iniStr;
    iniStr := iniFile.ReadString('Database', 'Password', '');
    if not iniStr.IsEmpty then
      ucKG.Password := iniStr;
    try
      ucKG.Connect;
    except
      on E: Exception do
      begin
        Logger.Log(5, 'Failed to connect to auth database: ' + E.Message);
      end;
    end;

    Logger.Log(1, '');
  finally
    IniFile.Free;
  end;
end;

procedure TAuthDatabase.DataModuleDestroy(Sender: TObject);
begin
  ucKG.Connected := false;
end;


end.
